pub async fn leaf_chain_with_upgrade(
range: impl IntoIterator<Item = u64>,
upgrade_height: u64,
upgrade: Upgrade,
) -> Vec<LeafQueryData<SeqTypes>>Expand description
Construct a valid leaf chain for the given height range.
The chain will upgrade from base to upgrade at height upgrade_height.